==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.bb = function () {
        return new MedianPriceIndicator();
    };
    MedianPriceIndicator.prototype.get_aaw = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "aaw", {
        get: function () {
            return this.get_aaw();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_aan = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "aan", {
        get: function () {
            return this.get_aan();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };

==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/MedianPriceIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MedianPriceIndicatorStrategy } from "./MedianPriceIndicatorStrategy";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
var MedianPriceIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MedianPriceIndicator, _super);
    function MedianPriceIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MedianPriceIndicator.prototype.bi = function () {
        return new MedianPriceIndicator();
    };
    MedianPriceIndicator.prototype.get_ab8 = function () {
        return new MedianPriceIndicatorStrategy();
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "ab8", {
        get: function () {
            return this.get_ab8();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.prototype.get_abz = function () {
        return MedianPriceIndicator.$;
    };
    Object.defineProperty(MedianPriceIndicator.prototype, "abz", {
        get: function () {
            return this.get_abz();
        },
        enumerable: false,
        configurable: true
    });
    MedianPriceIndicator.$t = markType(MedianPriceIndicator, 'MedianPriceIndicator', ItemwiseStrategyBasedIndicator.$);
    return MedianPriceIndicator;
}(ItemwiseStrategyBasedIndicator));
export { MedianPriceIndicator };
